@@ -1,5 +1,6 @@
 import React, { useEffect, useState } from 'react';
 import axios from 'axios';
+import Loader from 'react-loader-spinner';
 import { GET_CONFIRMATION_TEXT } from '../config/endpoints';
 import { setRoute } from '../redux/actions';
 import { connect } from 'react-redux';
@@ -7,27 +8,26 @@ import { connect } from 'react-redux';
 const Confirmation = ({ match, setRoute }) => {
     const [confirmations, setConfirmations] = useState([]);
     const updated = match.params.updated === '1';
+    const bookingId = match.params.bookingId;
 
     async function fetchData() {
-        const bookingId = match.params.bookingId;
-
         if (bookingId === null) return null;
-        axios
-            .get(GET_CONFIRMATION_TEXT, {
+        try {
+            const response = await axios.get(GET_CONFIRMATION_TEXT, {
                 params: {
                     bookingId
                 }
-            })
-            .then(response => {
-                setConfirmations(response.data);
-            })
-            .catch(err => console.warn(err));
+            });
+            setConfirmations(response.data);
+        } catch (err) {
+            console.warn(err);
+        }
     }
 
     useEffect(() => {
         fetchData();
         setRoute(6);
-    }, []);
+    }, [bookingId]);
 
     return (
         <div className="centered-container">
@@ -40,15 +40,21 @@ const Confirmation = ({ match, setRoute }) => {
                 </h1>
             )}
             <div className="confirmation" style={{ textAlign: 'left' }}>
-                {confirmations.map((confirmation, key) => {
-                    return (
-                        <p
-                            key={key}
-                            style={{ fontWeight: 600 }}
-                            dangerouslySetInnerHTML={{ __html: confirmation }}
-                        />
-                    );
-                })}
+                {confirmations.length === 0 ? (
+                    <div className="loadingSpinnerContainer">
+                        <Loader type="Oval" width={50} height={50} color="#088584" />
+                    </div>
+                ) : (
+                    confirmations.map((confirmation, key) => {
+                        return (
+                            <p
+                                key={key}
+                                style={{ fontWeight: 600 }}
+                                dangerouslySetInnerHTML={{ __html: confirmation }}
+                            />
+                        );
+                    })
+                )}
                 <p>
                     <strong>Your Ticket Confirmation is being sent to your email address</strong>
                 </p>
